import { BrowserCacheLocation, INavigationClient, LogLevel } from "@azure/msal-browser";
import { INetworkModule, LoggerOptions, ProtocolMode, SystemOptions } from "@azure/msal-common";
export declare type BrowserAuthOptions = {
    clientId: string;
    authority?: string;
    knownAuthorities?: Array<string>;
    cloudDiscoveryMetadata?: string;
    authorityMetadata?: string;
    redirectUri?: string;
    postLogoutRedirectUri?: string | null;
    navigateToLoginRequestUrl?: boolean;
    clientCapabilities?: Array<string>;
    protocolMode?: ProtocolMode;
};
export declare type CacheOptions = {
    cacheLocation?: BrowserCacheLocation | string;
    storeAuthStateInCookie?: boolean;
    secureCookies?: boolean;
};
export declare type BrowserSystemOptions = SystemOptions & {
    loggerOptions?: LoggerOptions;
    networkClient?: INetworkModule;
    navigationClient?: INavigationClient;
    windowHashTimeout?: number;
    iframeHashTimeout?: number;
    loadFrameTimeout?: number;
    navigateFrameWait?: number;
    redirectNavigationTimeout?: number;
    asyncPopups?: boolean;
    allowRedirectInIframe?: boolean;
};
export declare type Configuration = {
    auth: BrowserAuthOptions;
    cache?: CacheOptions;
    system?: BrowserSystemOptions;
};
export declare const loginRequest: {
    scopes: string[];
};
export declare const graphConfig: {
    graphUsersEndpoint: string;
    graphUserPhotoEndpoint: string;
    graphOrganizationEndpoint: string;
    msGraphBatchEndpoint: string;
    graphGetAppsFileEndpoint: string;
    graphSaveAppsFileEndpoint: string;
    graphSpecialFolderEndpoint: string;
    graphSearchEndpoint: string;
    graphSitesEndpoint: string;
    graphListItems: string;
    graphGetImageThumbnailEndPoint: string;
};
export declare const msalConfig: {
    auth: {
        clientId: string;
        redirectUri: string;
        postLogoutRedirectUri: string;
        mainWindowRedirectUri: string;
    };
    cache: {
        cacheLocation: string;
    };
    system: {
        loggerOptions: {
            loggerCallback: (level: LogLevel, message: string, containsPii: any) => void;
        };
    };
};
